
GBTRED
======

Green Bank Telescope L-band Data Reduction Software

Authors
-------

- **David Nidever** (Montana State University)

Installation
------------

To install the latest version::

    pip install git+https://github.com/dnidever/gbtred

License
-------

.. image:: http://img.shields.io/badge/license-MIT-blue.svg?style=flat
        :target: https://github.com/dnidever/gbtred/blob/main/LICENSE
